@@ -352,7 +352,6 @@ BOOL cmd_raise(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     return TRUE;
 }
 
-
 BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
@@ -853,13 +852,15 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         if(SFUN(fun).mArgBlocks && block_num < vector_count(SFUN(fun).mArgBlocks)) {
             sObject* block = vector_item(SFUN(fun).mArgBlocks, block_num);
-            sObject* fun = fun_clone_from_stack_block_stack(block, NULL);
 
-            if(!run_function(fun, nextin, nextout, runinfo, command->mArgsRuntime + 2, command->mArgsNumRuntime -2, command->mBlocks, command->mBlocksNum))
+            int rcode = 0;
+            if(!run(block, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) 
             {
+                sCommand* command = runinfo->mCommand;
+                err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = rcode;
                 return FALSE;
             }
-            //runinfo->mRCode = runinfo->mRCode;
         }
     }
     else {
