@@ -58,10 +58,12 @@ static BOOL entry_fun(sObject* nextin, sObject* nextout, sRunInfo* runinfo, sObj
     sObject* object = runinfo->mCurrentObject;
     sCommand* command = runinfo->mCommand;
 
+    BOOL no_stackframe = sCommand_option_item(command, "-copy-stackframe");
+
     if(type == T_CLASS) 
-        block = class_clone_from_stack_block_gc(block, TRUE, NULL); // block is a stack object, so change the memory manager from stack to gc
+        block = class_clone_from_stack_block_to_gc(block, TRUE, NULL, no_stackframe); // block is a stack object, so change the memory manager from stack to gc
     else
-        block = fun_clone_from_stack_block_gc(block, TRUE, NULL); // block is a stack object, so change the memory manager from stack to gc
+        block = fun_clone_from_stack_block_to_gc(block, TRUE, NULL, no_stackframe); // block is a stack object, so change the memory manager from stack to gc
 
     if(sCommand_option_item(command, "-inherit")) {
         sObject* parent = uobject_item(object, command->mArgsRuntime[1]);
@@ -1209,7 +1211,7 @@ BOOL cmd_mrun(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
 
     if(command->mBlocksNum == 1) {
-        sObject* klass = class_clone_from_stack_block_stack(command->mBlocks[0], NULL);
+        sObject* klass = class_clone_from_stack_block_to_stack(command->mBlocks[0], NULL, sCommand_option_item(command, "-copy-stackframe"));
 
         int rcode = 0;
         if(!run(SCLASS(klass).mBlock, nextin, nextout, &rcode, runinfo->mRecieverObject, runinfo->mRunningObject)) {
