@@ -410,8 +410,8 @@ BOOL cmd_index(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             char* result = NULL;
             if(sCommand_option_item(command, "-ignore-case")) {
                 while(p < start_byte + strlen(start_byte)) {
-                    if(gxyzshSigInt) {
-                        gxyzshSigInt = FALSE;
+                    if(gXyzshSigInt) {
+                        gXyzshSigInt = FALSE;
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
@@ -432,8 +432,8 @@ BOOL cmd_index(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
             else {
                 while(p < start_byte + strlen(start_byte)) {
-                    if(gxyzshSigInt) {
-                        gxyzshSigInt = FALSE;
+                    if(gXyzshSigInt) {
+                        gXyzshSigInt = FALSE;
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
@@ -471,7 +471,7 @@ BOOL cmd_index(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
 
-            ///  ///
+            /// Ω–Œœ ///
             if(!sCommand_option_item(command, "-quiet")) {
                 if(!fd_write(nextout, msg, size)) {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
@@ -503,9 +503,9 @@ static char* strstr_back(char* p, char* start, char* word, char* sname, int slin
                 break;
             }
 
-            if(gxyzshSigInt) {
+            if(gXyzshSigInt) {
                 err_msg("interrupt", sname, sline, command);
-                gxyzshSigInt = FALSE;
+                gXyzshSigInt = FALSE;
                 return NULL;
             }
         }
@@ -542,8 +542,8 @@ static char* strcasestr_back(char* p, char* start, char* word, char* sname, int
                 }
             }
 
-            if(gxyzshSigInt) {
-                gxyzshSigInt = FALSE;
+            if(gXyzshSigInt) {
+                gXyzshSigInt = FALSE;
                 err_msg("interrupt", sname, sline, command);
                 return NULL;
             }
@@ -629,8 +629,8 @@ BOOL cmd_rindex(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 while(p>=target) {
                     result = strcasestr_back(p, target, word, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
 
-                    if(gxyzshSigInt) {
-                        gxyzshSigInt = FALSE;
+                    if(gXyzshSigInt) {
+                        gXyzshSigInt = FALSE;
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
@@ -652,8 +652,8 @@ BOOL cmd_rindex(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 while(p>=target) {
                     result = strstr_back(p, target, word, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
 
-                    if(gxyzshSigInt) {
-                        gxyzshSigInt = FALSE;
+                    if(gXyzshSigInt) {
+                        gXyzshSigInt = FALSE;
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
                         return FALSE;
@@ -690,7 +690,7 @@ BOOL cmd_rindex(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
             }
 
-            ///  ///
+            /// Ω–Œœ ///
             if(!sCommand_option_item(command, "-quiet")) {
                 if(!fd_write(nextout, msg, size)) {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
