@@ -256,7 +256,6 @@ static BOOL read_env(char** p, sBuf* buf, char* sname, int* sline, BOOL expand_q
 
 static BOOL add_argument_to_command(sBuf* buf, sCommand* command, char* sname, int* sline);
 
-/// ñɤ߹
 static BOOL read_one_argument(char** p, sBuf* buf, char* sname, int* sline, BOOL expand_quote, sCommand* command, sObject* block, sObject** current_object)
 {
     BOOL squote = FALSE;
@@ -381,7 +380,7 @@ static BOOL read_one_argument(char** p, sBuf* buf, char* sname, int* sline, BOOL
                         return FALSE;
                     }
                 }
-                else if(gxyzshSigInt) {
+                else if(gXyzshSigInt) {
                     err_msg("signal interrupt", sname, *sline, "here document");
                     return FALSE;
                 }
@@ -655,7 +654,6 @@ void tilda_expasion(char* file, ALLOC char** file2)
     *file2 = STRDUP(result);
 }
 
-
 static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sname, int* sline, sObject** current_object);
 
 // result --> TRUE: success
@@ -1012,7 +1010,7 @@ static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sn
 }
 
 // result --> TRUE: success
-// result --> FALSE: There is a error message on gErrMsg. Please output the error message and stop running
+// result --> FALSE: There is an error message on gErrMsg. Please output the error message and stop running
 BOOL parse(char* p, char* sname, int* sline, sObject* block, sObject** current_object)
 {
     SBLOCK(block).mSource = STRDUP(p);
