@@ -581,10 +581,28 @@ BOOL run_function(sObject* fun, sObject* nextin, sObject* nextout, sRunInfo* run
     sRunInfo* runinfo2 = SFUN(fun).mRunInfo;
     SFUN(fun).mRunInfo = runinfo;
 
-    sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
-    vector_add(gStackFrames, stackframe);
-    //uobject_init(stackframe);
-    SFUN(fun).mLocalObjects = stackframe;
+    BOOL no_stackframe = SFUN(fun).mFlags & FUN_FLAGS_NO_STACKFRAME;
+
+    if(!no_stackframe) {
+        sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
+        vector_add(gStackFrames, stackframe);
+        //uobject_init(stackframe);
+        SFUN(fun).mLocalObjects = stackframe;
+    } else {
+        sObject* stackframe_before = vector_item(gStackFrames, vector_count(gStackFrames)-1);
+        sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
+        vector_add(gStackFrames, stackframe);
+        //uobject_init(stackframe);
+        SFUN(fun).mLocalObjects = stackframe;
+
+        uobject_it* it = uobject_loop_begin(stackframe_before);
+        while(it) {
+             sObject* object = uobject_loop_item(it);
+             char* key = uobject_loop_key(it);
+             uobject_put(stackframe, key, object);
+             it = uobject_loop_next(it);
+        }
+    }
 
     sObject* argv2 = VECTOR_NEW_GC(16, FALSE);
     int i;
@@ -631,7 +649,7 @@ BOOL run_function(sObject* fun, sObject* nextin, sObject* nextout, sRunInfo* run
 
     (void)vector_pop_back(gStackFrames);
 
-runinfo->mRCode = rcode;
+    runinfo->mRCode = rcode;
 
     SFUN(fun).mLocalObjects = local_objects;
     SFUN(fun).mArgBlocks = arg_blocks;
@@ -688,7 +706,7 @@ static BOOL run_object(sObject* object, sObject* nextin, sObject* nextout, sRunI
 
         case T_CLASS: {
             sCommand* command = runinfo->mCommand;
-            if(!run_function(object, nextin, nextout, runinfo, command->mArgsRuntime + 1, command->mArgsNumRuntime -1, command->mBlocks, command->mBlocksNum)){
+            if(!run_function(object, nextin, nextout, runinfo, command->mArgsRuntime + 1, command->mArgsNumRuntime -1, command->mBlocks, command->mBlocksNum)) {
                 return FALSE;
             }
             }
