@@ -326,7 +326,7 @@ int uobject_gc_children_mark(sObject* self)
     while(it) {
         sObject* item = it->mItem;
 
-        if((item->mFlg & GC_MARK) == 0) {
+        if(item && (item->mFlg & GC_MARK) == 0) {
             item->mFlg |= GC_MARK;
             count++;
 
