@@ -25,13 +25,11 @@ void sCommand_add_env_block(sCommand* self, sObject* block, BOOL double_dollar,
 void sCommand_add_env(sCommand* self, MANAGED char* name, MANAGED char* key, BOOL key_env, BOOL double_dollar);
 void sCommand_add_redirect_to_command(sCommand* self, MANAGED char* name, BOOL env, BOOL glob, int redirect);
 
-sObject* fun_clone_from_stack_block_gc(sObject* block, BOOL user_object, sObject* parent);
-sObject* fun_clone_from_stack_block_stack(sObject* block, sObject* parent);
+sObject* fun_clone_from_stack_block_to_gc(sObject* block, BOOL user_object, sObject* parent, BOOL no_stackframe);
+sObject* fun_clone_from_stack_block_to_stack(sObject* block, sObject* parent, BOOL no_stackframe);
 
-sObject* make_stack_fun_from_stack_block(sObject* self);
-
-sObject* class_clone_from_stack_block_gc(sObject* block, BOOL user_object, sObject* parent);
-sObject* class_clone_from_stack_block_stack(sObject* block, sObject* parent);
+sObject* class_clone_from_stack_block_to_gc(sObject* block, BOOL user_object, sObject* parent, BOOL no_stackframe);
+sObject* class_clone_from_stack_block_to_stack(sObject* block, sObject* parent, BOOL no_stackframe);
 
 #endif
 
