@@ -276,6 +276,8 @@ struct block_obj
 struct _sObject;
 struct _sRunInfo;
 
+#define FUN_FLAGS_NO_STACKFRAME 0x01
+
 typedef struct
 {
     struct _sObject* mBlock;
@@ -287,6 +289,8 @@ typedef struct
 
     option_hash_it* mOptions;
     struct _sRunInfo* mRunInfo;
+
+    char mFlags;
 } fun_obj;
 
 typedef fun_obj class_obj;
@@ -498,8 +502,8 @@ void nfun_delete_gc(sObject* self);
 BOOL nfun_put_option_with_argument(sObject* self, MANAGED char* key);
 BOOL nfun_option_with_argument_item(sObject* self, char* key);
 
-sObject* fun_new_from_gc(sObject* parent, BOOL user_object);
-#define FUN_NEW_GC(o, o2) fun_new_from_gc(o, o2)
+sObject* fun_new_from_gc(sObject* parent, BOOL user_object, BOOL no_stackframe);
+#define FUN_NEW_GC(o, o2, o3) fun_new_from_gc(o, o2, o3)
 void fun_delete_gc(sObject* self);
 int fun_gc_children_mark(sObject* self);
 #define FUN_NEW_STACK(o) fun_new_from_stack(o)
@@ -508,8 +512,8 @@ void fun_delete_stack(sObject* self);
 BOOL fun_put_option_with_argument(sObject* self, MANAGED char* key);
 BOOL fun_option_with_argument_item(sObject* self, char* key);
 
-sObject* class_new_from_gc(sObject* parent, BOOL user_object);
-#define CLASS_NEW_GC(o, o2) class_fun_new_from_gc(o, o2)
+sObject* class_new_from_gc(sObject* parent, BOOL user_object, BOOL no_stackframe);
+#define CLASS_NEW_GC(o, o2, o3) class_fun_new_from_gc(o, o2, o3)
 void class_delete_gc(sObject* self);
 void class_delete_stack(sObject* self);
 BOOL class_option_with_argument_item(sObject* self, char* key);
